
#include "csmanager.h"
#include "client.h"
#include "server.h"

CSManager::CSManager( int port, QString file_to_open,  
                      QObject * parent, const char * name)
	: QObject(parent, name )
{
	_port = port;
	_file_to_open = file_to_open;

	// Client which will try to connect to other running instance
	client = new MyClient( _port, this, "client");
	connect( client, SIGNAL(connected()), this, SLOT(connectedToPort()) );
	connect( client, SIGNAL(notConnected()), this, SLOT(notConnectedToPort()) );
	connect( client, SIGNAL(serverIdentified()), 
             this, SLOT(connectedToInstance()) );
	connect( client, SIGNAL(connectionClosed()), 
             this, SLOT(connectionToInstanceClosed()) );
	connect( client, SIGNAL(unknownServer()),
             this, SLOT(connectedToUnknownServer()) );
	connect( client, SIGNAL(serverDontRespond()),
             this, SLOT(serverDontRespond()) );
}

CSManager::~CSManager() {
}

void CSManager::connectedToPort() {
	qDebug("CSManager::connectedToPort");
}

void CSManager::notConnectedToPort() {
	qDebug("CSManager::notConnectedToPort");

	server = new MyServer( _port, this);
	connect(server, SIGNAL(receivedOpen(QString)),
            this, SIGNAL(requestOpen(QString)));
	connect(server, SIGNAL(receivedFunction(QString)),
            this, SIGNAL(requestFunction(QString)));

	emit mayStartUp( ServerStarted );
}

void CSManager::connectedToInstance() {
	qDebug("CSManager::connectedToInstance");

	if ( ! _file_to_open.isEmpty()) {
		//client->sendToServer("open " + _file_to_open);
		client->sendToServer("open_utf8 " + _file_to_open.utf8());
	}

	client->closeConnection();
}

void CSManager::connectionToInstanceClosed() {
	qDebug("CSManager::connectedToInstanceClosed");
	emit mayClose();
}

void CSManager::connectedToUnknownServer() {
	qDebug("CSManager::connectedToUnknownServer");
	qDebug("CSManager::connectedToUnknownServer: * Keeping running");

	emit mayStartUp( UnknownServerFound );
}

void CSManager::serverDontRespond() {
	qDebug("CSManager::serverDontRespond");

	emit mayStartUp( ServerDoesNotRespond );
}
